@@ -16,36 +16,42 @@ expect_no_reduction <- function(.prt, .df) {
 }
 
 test_that("part_icc() reduces correctly, high threshold", {
-  prt <- partition(df, threshold = .6)
+  prt <- expect_silent(partition(df, threshold = .6))
   expect_mapping_names(c("block1_x3", "block1_x5", "reduced_var_1"), prt)
   expect_mapping_info(c(1, 1, 0.600), prt)
 })
 
 test_that("part_icc() reduces correctly, low threshold", {
-  prt <- partition(df, threshold = .1)
+  prt <- expect_silent(partition(df, threshold = .1))
   expect_mapping_names("reduced_var_1", prt)
   expect_mapping_info(0.553, prt)
 })
 
 test_that("part_icc() reduces correctly, independent data", {
-  ind_prt <- partition(ind_df, threshold = .8)
+  ind_prt <- expect_silent(partition(ind_df, threshold = .8))
   expect_no_reduction(ind_prt, ind_df)
 })
 
 test_that("part_kmeans() reduces correctly, high threshold", {
-  prt <- partition(df, threshold = .6, partitioner = part_kmeans())
+  prt <- expect_silent(
+    partition(df, threshold = .6, partitioner = part_kmeans())
+  )
   expect_mapping_names(c("reduced_var_1", "block1_x2", "block1_x3", "block1_x5"), prt)
   expect_mapping_info(c(0.673, 1, 1, 1), prt)
 })
 
 test_that("part_kmeans() reduces correctly, low threshold", {
-  prt <- partition(df, threshold = .1, partitioner = part_kmeans())
+  prt <- expect_silent(
+    partition(df, threshold = .1, partitioner = part_kmeans())
+  )
   expect_mapping_names("reduced_var_1", prt)
   expect_mapping_info(0.553, prt)
 })
 
 test_that("part_kmeans() reduces correctly, independent data", {
-  ind_prt <- partition(ind_df, threshold = .8, partitioner = part_kmeans())
+  ind_prt <- expect_silent(
+    partition(ind_df, threshold = .8, partitioner = part_kmeans())
+  )
   expect_no_reduction(ind_prt, ind_df)
 })
 
